@@ -1,3 +1,4 @@
+"""Classes and methods relevant for all CWL Proccess types."""
 import abc
 import copy
 import functools
@@ -266,7 +267,6 @@ def stage_files(
     fix_conflicts: bool = False,
 ) -> None:
     """Link or copy files to their targets. Create them as needed."""
-
     targets = {}  # type: Dict[str, MapperEnt]
     for key, entry in pathmapper.items():
         if "File" not in entry.type:
@@ -864,9 +864,10 @@ hints:
                     runtime_context.stagedir or tempfile.mkdtemp()
                 )
 
-        cwl_version = cast(str, self.metadata.get(
-            "http://commonwl.org/cwltool#original_cwlVersion", None
-        ))
+        cwl_version = cast(
+            str,
+            self.metadata.get("http://commonwl.org/cwltool#original_cwlVersion", None),
+        )
         builder = Builder(
             job,
             files,
@@ -1234,7 +1235,10 @@ def scandeps(
                     if nestdirs:
                         deps = nestdir(base, deps)
                     r.append(deps)
-            elif k not in ("listing", "secondaryFiles"):
+            elif doc.get("class") in ("File", "Directory") and k in ("listing", "secondaryFiles"):
+                # should be handled earlier.
+                pass
+            else:
                 r.extend(
                     scandeps(
                         base,
